@@ -2,7 +2,7 @@ package Minilla;
 use strict;
 use warnings;
 use 5.008005;
-use version; our $VERSION = version->declare("v3.0.7");
+use version; our $VERSION = version->declare("v3.0.8");
 
 our $DEBUG;
 our $AUTO_INSTALL;
@@ -13,7 +13,7 @@ sub auto_install { $AUTO_INSTALL }
 1;
 __END__
 
-=for stopwords MINILLA .mailmap mimick XSUtil travis XSUtil.needs_compiler_cpp XSUtil.generate_xshelper_h XSUtil.cc_warnings DarkPAN
+=for stopwords MINILLA .mailmap mimick XSUtil travis XSUtil.needs_compiler_cpp XSUtil.generate_xshelper_h XSUtil.cc_warnings DarkPAN minilla untracked UploadToCPAN circleci appveyor codecov gitter metacpan MBTiny
 
 =encoding utf8
 
@@ -107,7 +107,7 @@ Checking git's untracked files. If there's untracked files, minilla will abort.
 
 =head2 CheckOrigin
 
-This step will run the `git remote`. If there's no remote, minillla will abort.
+This step will run the `git remote`. If there's no remote, minilla will abort.
 
 =head2 BumpVersion
 
@@ -388,6 +388,14 @@ or program. Build fail if the command does not exist.
 Use a different module to generate C<README.md> from your pod. This
 module must subclass L<Pod::Markdown>.
 
+=item Metadata
+
+    [Metadata]
+    x_static_install = 1
+    x_deprecated = 1
+
+Add arbitrary keys to C<META.json>/C<META.yml>.
+
 =back
 
 =head1 FAQ
